==> fr-facturier-2.1.1.tbz: www/facturier/sql/facturier.sql <==
# Script de creation de base de donnes sous mysql
#pour la version 2.1 du facturier
#
# Host: ungi58    Database: FACTURIER
#--------------------------------------------------------
# Server version	3.23.41

#
# Table structure for table 'banque'
#

create database FACTURIER;
use FACTURIER;



CREATE TABLE banque (
  mois varchar(55) NOT NULL default '',
  annee varchar(55) NOT NULL default '',
  montant double NOT NULL default '0',
  PRIMARY KEY  (mois,annee)
) TYPE=MyISAM;

#
# Table structure for table 'client'
#

CREATE TABLE client (
  clientid int(10) unsigned NOT NULL default '0',
  clientnom varchar(100) NOT NULL default '',
  clientnom2 varchar(250) NOT NULL default '',
  clienttitre varchar(250) NOT NULL default '',
  clientville varchar(100) NOT NULL default '',
  clientrue1 varchar(255) NOT NULL default '',
  clientrue2 varchar(250) NOT NULL default '',
  clientcp varchar(255) NOT NULL default '',
  clientpays varchar(250) NOT NULL default '',
  tel1 varchar(255) NOT NULL default '',
  tel2 varchar(255) NOT NULL default '',
  email varchar(255) NOT NULL default '',
  fax varchar(255) NOT NULL default '',
  commentcli blob NOT NULL,
  statut varchar(20) NOT NULL default 'client',
  secteur_act varchar(255) NOT NULL default '',
  ca double NOT NULL default '0',
  soc_mere varchar(255) NOT NULL default '',
  clientcommercial varchar(255) NOT NULL default 'aucun',
  PRIMARY KEY  (clientid)
) TYPE=MyISAM;

#
# Table structure for table 'commande'
#

CREATE TABLE commande (
  numcde int(10) unsigned NOT NULL default '0',
  refcommande varchar(255) NOT NULL default '',
  libcde blob NOT NULL,
  datecde bigint(20) unsigned NOT NULL default '0',
  datefact bigint(20) unsigned NOT NULL default '0',
  commercial varchar(255) NOT NULL default '',
  chefprojet varchar(255) NOT NULL default '',
  nomcli int(11) NOT NULL default '0',
  montcde double NOT NULL default '0',
  commentaires blob NOT NULL,
  PRIMARY KEY  (numcde)
) TYPE=MyISAM;

#
# Table structure for table 'contactclient'
#

CREATE TABLE contactclient (
  contactid int(10) unsigned NOT NULL default '0',
  clientid int(10) unsigned NOT NULL default '0',
  contacttel varchar(255) NOT NULL default '',
  contactmail varchar(255) NOT NULL default '',
  contactnom varchar(255) NOT NULL default '',
  contactfonction varchar(255) NOT NULL default '',
  contactprenom varchar(255) NOT NULL default '',
  PRIMARY KEY  (contactid)
) TYPE=MyISAM;

#
# Table structure for table 'depenses'
#

CREATE TABLE depenses (
  depenseid int(10) unsigned NOT NULL default '0',
  libdep varchar(255) NOT NULL default '',
  MontHt double NOT NULL default '0',
  MontTTC double NOT NULL default '0',
  datefact bigint(20) NOT NULL default '0',
  numcheque varchar(60) NOT NULL default '',
  fournisseur varchar(255) NOT NULL default '',
  PRIMARY KEY  (depenseid)
) TYPE=MyISAM;

#
# Table structure for table 'facture'
#

CREATE TABLE facture (
  numfact int(10) unsigned NOT NULL default '0',
  clientidfact int(11) NOT NULL default '0',
  clientlog varchar(20) default NULL,
  responsablecde varchar(60) NOT NULL default '',
  refcde varchar(255) NOT NULL default '',
  datefact bigint(20) unsigned NOT NULL default '0',
  datereglement bigint(20) unsigned NOT NULL default '0',
  dateecheance bigint(20) unsigned NOT NULL default '0',
  echeance varchar(20) NOT NULL default '30',
  numcheque varchar(60) NOT NULL default '',
  contact varchar(60) NOT NULL default '',
  banquereglement varchar(255) NOT NULL default '',
  statutfact int(11) NOT NULL default '2',
  fraisdeplt double NOT NULL default '0',
  totHT double NOT NULL default '0',
  totTTC double NOT NULL default '0',
  envoi tinyint(4) NOT NULL default '0',
  paiement varchar(255) NOT NULL default '',
  periodicite varchar(255) NOT NULL default '0',
  commentaires blob NOT NULL,
  PRIMARY KEY  (numfact),
  KEY cde (refcde)
) TYPE=MyISAM;

#
# Table structure for table 'lig_facture'
#

CREATE TABLE lig_facture (
  ligfact int(10) unsigned NOT NULL default '0',
  numfact int(11) NOT NULL default '0',
  libartic char(255) NOT NULL default '',
  qtefacture float NOT NULL default '0',
  prixHT double NOT NULL default '0',
  tauxTVA float NOT NULL default '0',
  complement tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (ligfact),
  KEY numfact (numfact)
) TYPE=MyISAM;

#
# Table structure for table 'propal'
#

CREATE TABLE propal (
  idpropal int(10) unsigned NOT NULL default '0',
  libpropal varchar(255) NOT NULL default '',
  datepropal bigint(20) unsigned NOT NULL default '0',
  nomcli int(10) unsigned NOT NULL default '0',
  commercial varchar(255) NOT NULL default '',
  chefprojet varchar(255) NOT NULL default '',
  pourcestim varchar(20) NOT NULL default '',
  total double NOT NULL default '0',
  commentaires blob NOT NULL,
  PRIMARY KEY  (idpropal)
) TYPE=MyISAM;

#
# Table structure for table 'relance'
#

CREATE TABLE relance (
  idrelance int(10) unsigned NOT NULL default '0',
  numfact int(10) unsigned NOT NULL default '0',
  daterelance bigint(20) unsigned NOT NULL default '0',
  PRIMARY KEY  (idrelance)
) TYPE=MyISAM;

#
# Table structure for table 'tacheclient'
#

CREATE TABLE tacheclient (
  tacheid int(10) unsigned NOT NULL default '0',
  clientid int(11) NOT NULL default '-1',
  tachedate bigint(20) unsigned NOT NULL default '0',
  tachelibelle varchar(255) NOT NULL default '0',
  tacheheure varchar(255) NOT NULL default '00:00',
  tacheuserid int(10) unsigned NOT NULL default '0',
  tachefait tinyint(4) NOT NULL default '1',
  PRIMARY KEY  (tacheid)
) TYPE=MyISAM;

#
# Table structure for table 'tacheuserdroit'
#

CREATE TABLE tacheuserdroit (
  tacheuserid int(10) unsigned NOT NULL default '0',
  useridlu int(10) unsigned NOT NULL default '0',
  useridli int(10) unsigned NOT NULL default '0',
  droitmaj tinyint(4) NOT NULL default '0',
  droitsupp tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (tacheuserid)
) TYPE=MyISAM;

#
# Table structure for table 'utilisateur'
#

CREATE TABLE utilisateur (
  userid int(10) unsigned NOT NULL default '0',
  userlogin varchar(20) NOT NULL default '',
  username varchar(255) NOT NULL default '',
  userpasswd varchar(20) NOT NULL default '',
  clientiduser int(11) default '-1',
  userrole varchar(255) NOT NULL default '',
  session int(11) NOT NULL default '0',
  nomcomplet varchar(255) default NULL,
  PRIMARY KEY  (userid),
  UNIQUE KEY login (userlogin)
) TYPE=MyISAM;

INSERT INTO  utilisateur VALUES (1,'demo','demo','igVbRzyvXqx2c',-1,'admin',0,'demo');

==> fr-facturier-2.1.2.tbz: www/facturier/sql/facturier.sql <==

create database FACTURIER;
use FACTURIER;

#
# Table structure for table 'article'
#

CREATE TABLE article (
  codart varchar(18) NOT NULL default '0',
  desart varchar(60) NOT NULL default '0',
  codfam varchar(8) NOT NULL default '0',
  qtestk double NOT NULL default '0',
  pxht double default '0',
  codunit varchar(4) NOT NULL default '0',
  idartic int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (codart),
  UNIQUE KEY codart (codart),
  UNIQUE KEY id_art (idartic),
  KEY codfam (codfam)
) TYPE=MyISAM;

#
# Table structure for table 'banque'
#

CREATE TABLE banque (
  mois varchar(55) NOT NULL default '',
  annee varchar(55) NOT NULL default '',
  montant double NOT NULL default '0',
  PRIMARY KEY  (mois,annee)
) TYPE=MyISAM;

#
# Table structure for table 'client'
#

CREATE TABLE client (
  clientid int(10) unsigned NOT NULL default '0',
  clientnom varchar(100) NOT NULL default '',
  clientnom2 varchar(250) NOT NULL default '',
  clienttitre varchar(250) NOT NULL default '',
  clientville varchar(100) NOT NULL default '',
  clientrue1 varchar(255) NOT NULL default '',
  clientrue2 varchar(250) NOT NULL default '',
  clientcp varchar(255) NOT NULL default '',
  clientpays varchar(250) NOT NULL default '',
  tel1 varchar(255) NOT NULL default '',
  tel2 varchar(255) NOT NULL default '',
  email varchar(255) NOT NULL default '',
  fax varchar(255) NOT NULL default '',
  commentcli blob NOT NULL,
  statut varchar(20) NOT NULL default 'client',
  secteur_act varchar(255) NOT NULL default '',
  ca double NOT NULL default '0',
  soc_mere varchar(255) NOT NULL default '',
  clientcommercial varchar(255) NOT NULL default 'aucun',
  remise_defaut double NOT NULL default '0',
  clientresponsable varchar(100) NOT NULL default '',
  PRIMARY KEY  (clientid)
) TYPE=MyISAM;

#
# Table structure for table 'commande'
#

CREATE TABLE commande (
  numcde int(10) unsigned NOT NULL default '0',
  refcommande varchar(255) NOT NULL default '',
  libcde blob NOT NULL,
  datecde bigint(20) unsigned NOT NULL default '0',
  datefact bigint(20) unsigned NOT NULL default '0',
  commercial varchar(255) NOT NULL default '',
  chefprojet varchar(255) NOT NULL default '',
  nomcli int(11) NOT NULL default '0',
  montcde double NOT NULL default '0',
  commentaires blob NOT NULL,
  PRIMARY KEY  (numcde)
) TYPE=MyISAM;

#
# Table structure for table 'contactclient'
#

CREATE TABLE contactclient (
  contactid int(10) unsigned NOT NULL default '0',
  clientid int(10) unsigned NOT NULL default '0',
  contacttel varchar(255) NOT NULL default '',
  contactmail varchar(255) NOT NULL default '',
  contactnom varchar(255) NOT NULL default '',
  contactfonction varchar(255) NOT NULL default '',
  contactprenom varchar(255) NOT NULL default '',
  PRIMARY KEY  (contactid)
) TYPE=MyISAM;

#
# Table structure for table 'depenses'
#

CREATE TABLE depenses (
  depenseid int(10) unsigned NOT NULL default '0',
  libdep varchar(255) NOT NULL default '',
  MontHt double NOT NULL default '0',
  MontTTC double NOT NULL default '0',
  datefact bigint(20) NOT NULL default '0',
  numcheque varchar(60) NOT NULL default '',
  fournisseur varchar(255) NOT NULL default '',
  PRIMARY KEY  (depenseid)
) TYPE=MyISAM;

#
# Table structure for table 'facture'
#

CREATE TABLE facture (
  numfact int(10) unsigned NOT NULL default '0',
  clientidfact int(11) NOT NULL default '0',
  clientlog varchar(20) default NULL,
  responsablecde varchar(60) NOT NULL default '',
  refcde varchar(255) NOT NULL default '',
  datefact bigint(20) unsigned NOT NULL default '0',
  datereglement bigint(20) unsigned NOT NULL default '0',
  dateecheance bigint(20) unsigned NOT NULL default '0',
  echeance varchar(20) NOT NULL default '30',
  numcheque varchar(60) NOT NULL default '',
  contact varchar(60) NOT NULL default '',
  banquereglement varchar(255) NOT NULL default '',
  statutfact int(11) NOT NULL default '2',
  fraisdeplt double NOT NULL default '0',
  totHT double NOT NULL default '0',
  totTTC double NOT NULL default '0',
  envoi tinyint(4) NOT NULL default '0',
  paiement varchar(255) NOT NULL default '',
  periodicite varchar(255) NOT NULL default '0',
  commentaires blob NOT NULL,
  remise double NOT NULL default '0',
  totHTremise double NOT NULL default '0',
  PRIMARY KEY  (numfact),
  KEY cde (refcde)
) TYPE=MyISAM;

#
# Table structure for table 'famart'
#

CREATE TABLE famart (
  codfam char(8) NOT NULL default '0',
  desfam char(60) NOT NULL default '0',
  idfamart int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (codfam),
  UNIQUE KEY desfam (desfam)
) TYPE=MyISAM;

#
# Table structure for table 'lig_facture'
#

CREATE TABLE lig_facture (
  ligfact int(10) unsigned NOT NULL default '0',
  numfact int(11) NOT NULL default '0',
  libartic varchar(255) NOT NULL default '',
  qtefacture float NOT NULL default '0',
  prixHT double NOT NULL default '0',
  tauxTVA float NOT NULL default '0',
  complement tinyint(4) NOT NULL default '0',
  codart varchar(10) NOT NULL default '-',
  idartic int(10) unsigned default NULL,
  PRIMARY KEY  (ligfact),
  KEY numfact (numfact)
) TYPE=MyISAM;

#
# Table structure for table 'propal'
#

CREATE TABLE propal (
  idpropal int(10) unsigned NOT NULL default '0',
  libpropal varchar(255) NOT NULL default '',
  datepropal bigint(20) unsigned NOT NULL default '0',
  nomcli int(10) unsigned NOT NULL default '0',
  commercial varchar(255) NOT NULL default '',
  chefprojet varchar(255) NOT NULL default '',
  pourcestim varchar(20) NOT NULL default '',
  total double NOT NULL default '0',
  commentaires blob NOT NULL,
  PRIMARY KEY  (idpropal)
) TYPE=MyISAM;

#
# Table structure for table 'relance'
#

CREATE TABLE relance (
  idrelance int(10) unsigned NOT NULL default '0',
  numfact int(10) unsigned NOT NULL default '0',
  daterelance bigint(20) unsigned NOT NULL default '0',
  PRIMARY KEY  (idrelance)
) TYPE=MyISAM;

#
# Table structure for table 'tacheclient'
#

CREATE TABLE tacheclient (
  tacheid int(10) unsigned NOT NULL default '0',
  clientid int(11) NOT NULL default '-1',
  tachedate bigint(20) unsigned NOT NULL default '0',
  tachelibelle varchar(255) NOT NULL default '0',
  tacheheure varchar(255) NOT NULL default '00:00',
  tacheuserid int(10) unsigned NOT NULL default '0',
  tachefait tinyint(4) NOT NULL default '1',
  PRIMARY KEY  (tacheid)
) TYPE=MyISAM;

#
# Table structure for table 'tacheuserdroit'
#

CREATE TABLE tacheuserdroit (
  tacheuserid int(10) unsigned NOT NULL default '0',
  useridlu int(10) unsigned NOT NULL default '0',
  useridli int(10) unsigned NOT NULL default '0',
  droitmaj tinyint(4) NOT NULL default '0',
  droitsupp tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (tacheuserid)
) TYPE=MyISAM;

#
# Table structure for table 'unite'
#

CREATE TABLE unite (
  codunit char(4) NOT NULL default '0',
  desunit char(24) NOT NULL default '0',
  idunit int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (codunit),
  KEY codunit (codunit)
) TYPE=MyISAM;

#
# Table structure for table 'utilisateur'
#

CREATE TABLE utilisateur (
  userid int(10) unsigned NOT NULL default '0',
  userlogin varchar(20) NOT NULL default '',
  username varchar(255) NOT NULL default '',
  userpasswd varchar(20) NOT NULL default '',
  clientiduser int(11) default '-1',
  userrole varchar(255) NOT NULL default '',
  session int(11) NOT NULL default '0',
  nomcomplet varchar(255) default NULL,
  PRIMARY KEY  (userid),
  UNIQUE KEY login (userlogin)
) TYPE=MyISAM;

INSERT INTO  utilisateur VALUES (1,'demo','demo','igVbRzyvXqx2c',-1,'admin',0,'demo');
